@@ -29,7 +29,7 @@ without store, and shortcuts around all middleman resenders.
 
 =head1 SEE ALSO
 
-Mail::SRS
+L<Mail::SRS>
 
 =cut
 
